@@ -17,31 +17,26 @@ class ServiceClient:
         self._token = token
 
     def resolve_universe(self, name: str) -> str:
-        u = self._build_url(f'universe/resolve/{name}')
+        u = self._build_url(f'resolve/universe', {'i': name})
         return self.__get(u)
 
     def load_universe(self, universe_id: str) -> Union[Universe, None]:
         params = {
             'o': '1',
         }
-        if self._token:
-            params['t'] = self._token
         u = self._build_url(f'universe/{universe_id}/export', params)
         universe_def = self.__get(u, 'bytes')
         return load_universe(universe_def)
 
     def get_layer_profile(self, profile_id: str) -> Union[LayerProfile, None]:
-        params = {}
-        if self._token:
-            params['t'] = self._token
-        u = self._build_url(f'space/profile_tokens/{profile_id}', params)
+        u = self._build_url(f'profile/{profile_id}/tokens')
         layer_profile_str = self.__get(u, 'text')
         return read_layer_profile(layer_profile_str)
 
     def _build_url(self, endpoint: str, params: Union[dict, None] = None):
         if params:
-            return f'{self._url}/{endpoint}?{"&".join([k + "=" + v for k, v in params.items()])}'
-        return f'{self._url}/{endpoint}'
+            return f'{self._url}/v1/{endpoint}?{"&".join([k + "=" + v for k, v in params.items()])}'
+        return f'{self._url}/v1/{endpoint}'
 
     def __get(self, url: str, return_type: str = 'json') -> any:
         resp = requests.get(url, headers=self._get_headers(), timeout=self._timeout)
@@ -69,4 +64,6 @@ class ServiceClient:
     def _get_headers(self, headers=None):
         if not headers:
             headers = {}
+        if self._token:
+            headers['Authorization'] = f'Bearer {self._token}'
         return headers
