@@ -6,7 +6,7 @@ from typing import Callable, List, Union
 
 from .access import LayerToken, LayerProfile
 from .types import ReturnType, FormatType, MappingType, FieldType
-from .resource import ResourceInstance, ResourceList, Resource
+from .resource import ResourceInstance, ResourceSpecials, Resource
 from ..util import JSONVal
 
 
@@ -362,11 +362,11 @@ class SystemClient:
 
     def get_resource_instance(self, resource: ResourceInstance, **kwargs):
         endpoint = self._build_url(f'resource/get')
-        return self._post(endpoint, resource.to_request(), **kwargs)
+        return self._post(endpoint, resource.to_get_request(), **kwargs)
 
-    def get_resource_list(self, resource: ResourceList, **kwargs):
+    def get_resource_specials(self, resource: ResourceSpecials, **kwargs):
         endpoint = self._build_url(f'resource/get')
-        return self._post(endpoint, resource.to_request(), **kwargs)
+        return self._post(endpoint, resource.to_get_request(), **kwargs)
 
     def _put_resource(self, resource: Resource, value: any, access_name: str, **kwargs):
         layer_id = self.__fetch_layer_id(access_name)
@@ -384,12 +384,12 @@ class SystemClient:
     def put_resource_instance(self, resource: ResourceInstance, value: any, access_name: str, **kwargs) -> Union[str, None]:
         return self._put_resource(resource, value, access_name, **kwargs)
 
-    def put_resource_list(self, resource: ResourceList, value: List[any], access_name: str, **kwargs) -> Union[List[str], None]:
+    def put_resource_specials(self, resource: ResourceSpecials, value: List[any], access_name: str, **kwargs) -> Union[List[str], None]:
         return self._put_resource(resource, value, access_name, **kwargs)
 
     # API helpers
 
-    def _build_url(self, endpoint: str, params: Union[dict, None] = None):
+    def  _build_url(self, endpoint: str, params: Union[dict, None] = None):
         if params:
             return f'{self._url}/v1/{endpoint}?{"&".join([k + "=" + v for k, v in params.items()])}'
         return f'{self._url}/v1/{endpoint}'
